==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Carousel.pm <==
package WebGUI::i18n::Dutch::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1242720820',
    'message' => 'Carrousel'
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1250840340',
    'message' => 'De breedte in pixels. De Carousel zal zich niet aanpassen aan inhoud met verschillende afmetingen. Door deze breedte in te stellen, zal de pagina goed gerenderd worden. Als de standaard breedte, 0, ingesteld blijft staan, wordt de breedte die van het eerste element.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1250840229',
    'message' => 'Breedte carouseldia'
  },
  'carousel template description' => {
    'lastUpdated' => '1242720862',
    'message' => 'Selecteer een sjabloon voor de carrousel'
  },
  'carousel template help title' => {
    'lastUpdated' => '1242720884',
    'message' => 'Carrousel sjabloon variabelen'
  },
  'carousel template label' => {
    'lastUpdated' => '1242720906',
    'message' => 'Carrousel sjabloon'
  },
  'id description' => {
    'lastUpdated' => '1242720940',
    'message' => 'Geef een uniek ID aan voor dit carrousel item'
  },
  'id label' => {
    'lastUpdated' => '1242720970',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1242721005',
    'message' => 'Het ID van het carrousel item'
  },
  'item_loop' => {
    'lastUpdated' => '1242721093',
    'message' => 'Een loop met daarin alle carrousel items'
  },
  'items description' => {
    'lastUpdated' => '1242721120',
    'message' => 'Geef de carrousel items in'
  },
  'items label' => {
    'lastUpdated' => '1242721133',
    'message' => 'Items'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1242721200',
    'message' => 'Het reeksnummer van het carrousel item'
  },
  'slideWidth' => {
    'lastUpdated' => '1250840201',
    'message' => 'De breedte voor elke dia in de Carousel'
  },
  'text' => {
    'lastUpdated' => '1242721226',
    'message' => 'De tekst van het carrousel item'
  }
}
;

1;

==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Carousel.pm <==
package WebGUI::i18n::Dutch::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1242720820',
    'message' => 'Carrousel'
  },
  'carousel slideHeight description' => {
    'lastUpdated' => '1280491551',
    'message' => 'De hoogte in pixels. De Carousel zal zich niet aanpassen aan inhoud met verschillende afmetingen. Door deze hoogte in te stellen, zal de pagina goed gerenderd worden. Als de standaard hoogte, 0, ingesteld blijft staan, wordt de hoogte die van het eerste element.'
  },
  'carousel slideHeight label' => {
    'lastUpdated' => '1280214520',
    'message' => 'Hoogte carouseldia'
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1250840340',
    'message' => 'De breedte in pixels. De Carousel zal zich niet aanpassen aan inhoud met verschillende afmetingen. Door deze breedte in te stellen, zal de pagina goed gerenderd worden. Als de standaard breedte, 0, ingesteld blijft staan, wordt de breedte die van het eerste element.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1250840229',
    'message' => 'Breedte carouseldia'
  },
  'carousel template description' => {
    'lastUpdated' => '1242720862',
    'message' => 'Selecteer een sjabloon voor de carrousel'
  },
  'carousel template help title' => {
    'lastUpdated' => '1242720884',
    'message' => 'Carrousel sjabloon variabelen'
  },
  'carousel template label' => {
    'lastUpdated' => '1242720906',
    'message' => 'Carrousel sjabloon'
  },
  'id description' => {
    'lastUpdated' => '1242720940',
    'message' => 'Geef een uniek ID aan voor dit carrousel item'
  },
  'id label' => {
    'lastUpdated' => '1242720970',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1242721005',
    'message' => 'Het ID van het carrousel item'
  },
  'item_loop' => {
    'lastUpdated' => '1242721093',
    'message' => 'Een loop met daarin alle carrousel items'
  },
  'items description' => {
    'lastUpdated' => '1242721120',
    'message' => 'Geef de carrousel items in'
  },
  'items label' => {
    'lastUpdated' => '1242721133',
    'message' => 'Items'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1242721200',
    'message' => 'Het reeksnummer van het carrousel item'
  },
  'slideHeight' => {
    'lastUpdated' => '1280214489',
    'message' => 'De hoogte voor elke dia in de Carousel.'
  },
  'slideWidth' => {
    'lastUpdated' => '1250840201',
    'message' => 'De breedte voor elke dia in de Carousel'
  },
  'text' => {
    'lastUpdated' => '1242721226',
    'message' => 'De tekst van het carrousel item'
  }
}
;

1;
